# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from functools import partial

from odoo import api, fields, models, tools, _

class PosOrder(models.Model):
      _inherit = "pos.order"

      @api.model
      def _order_fields(self, ui_order):
          process_line = partial(self.env['pos.order.line']._order_line_fields)
          return {
                'name':         ui_order['name'],
                'user_id':      ui_order['user_id'] or False,
                'session_id':   ui_order['pos_session_id'],
                'lines':        [process_line(l) for l in ui_order['lines']] if ui_order['lines'] else False,
                'pos_reference': ui_order['pos_reference'],
                'partner_id':   ui_order['partner_id'] or False,
                'date_order':   ui_order['creation_date'],
                'fiscal_position_id': ui_order['fiscal_position_id']
          }

      @api.model
      def create(self, values):
          if values.get('session_id'):
             # set name based on the sequence specified on the config
             session = self.env['pos.session'].browse(values['session_id'])
             values['name'] = session.config_id.sequence_id._next()
             values.setdefault('pricelist_id', session.config_id.pricelist_id.id)
             values['pos_reference']= self.env['ir.sequence'].next_by_code('pos.receipt.reference')
          else:
             # fallback on any pos.order sequence
             values['name'] = self.env['ir.sequence'].next_by_code('pos.order')
          return super(PosOrder, self).create(values)