odoo.define('point_of_sale.models_extension', function (require) {
"use strict";

var pos_model = require('point_of_sale.models');
var _super_posmodel = pos_model.PosModel.prototype;
var _super_ordermodel = pos_model.Order.prototype;

pos_model.load_models({model:  'ir.sequence',
          fields: ['prefix','number_next_actual'],
          domain: function(self){ return [['id','=', self.config.reciept_sequence_id[0]]]; },
          loaded: function(self,sequences){
             self.sequence = sequences[0];
             self.number_next = self.sequence.number_next_actual;
          },
          });

pos_model.PosModel = pos_model.PosModel.extend({
    initialize: function(session, attributes) {
        _super_posmodel.initialize.apply(this, arguments);
        this.number_next = null;
        this.sequence = null;

    },
});


pos_model.Order = pos_model.Order.extend({
     initialize: function(attributes,options){
        _super_ordermodel.initialize.apply(this, arguments);
        this.pos_reference = this.generate_sequence_id();
     },

    init_from_JSON: function(json) {
        this.pos_reference = json.pos_reference;
        _super_ordermodel.init_from_JSON.apply(this, arguments);
    },

    export_as_JSON: function() {
        var receipt = _super_ordermodel.export_as_JSON.apply(this, arguments);
        receipt['pos_reference'] = this.get_pos_reference();
        return receipt;
    },

    export_for_printing: function(){
        var receipt = _super_ordermodel.export_for_printing.apply(this, arguments);
        receipt['pos_reference'] = this.get_pos_reference();
        return receipt;
    },
    generate_sequence_id: function() {
            // Generates a public identification number for the order.
            // The generated number must be unique and sequential. They are made 12 digit long
            // to fit into EAN-13 barcodes, should it be needed
            function zero_pad(num,size){
                var s = "";
                var d = num.length
                while ( d < size) {
                    s = "0" + s;
                    d ++;
                }
                s = s+num;
                return s;
            }

            var prefix_sequence = this.pos.sequence.prefix.toString();
            var next_number = (this.pos.number_next).toString();
            this.pos.number_next ++;
            return zero_pad(prefix_sequence,4) +
                   zero_pad(next_number,5);
    },

    get_pos_reference: function() {
        return this.pos_reference;
    },

});

});